"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const HttpError_1 = require("vados-utils/lib/HttpError");
class Checker {
    static is(value, type, fieldName) {
        if (!(type instanceof Array)) {
            switch (type) {
                case Number:
                    if (isNaN(value))
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be Number type`);
                    return;
                case Date:
                    if (!(value instanceof Date))
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be Date type`);
                    return;
                case Boolean:
                    if (typeof value !== 'boolean' && !(value instanceof Boolean))
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be Boolean type`);
                    return;
                case Array:
                    if (!(value instanceof Array))
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be Array type`);
                    return;
                case Object:
                    if (typeof value !== 'object')
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be Object type`);
                    return;
                case String:
                    if (typeof value !== 'string' && !(value instanceof String))
                        throw HttpError_1.default.BAD_REQUEST(`${fieldName} must be String type`);
                    return;
                default:
                    return;
            }
        }
        const msgs = [];
        for (const e of type) {
            try {
                Checker.is(value, e, fieldName);
                return;
            }
            catch (e) {
                msgs.push(e.message);
            }
        }
        if (msgs.length > 0) {
            throw HttpError_1.default.BAD_REQUEST(msgs.join(' or '));
        }
    }
    static option(obj, field, type, defaultValue) {
        let fieldname;
        let msg;
        if (field instanceof Array) {
            fieldname = field[0];
            msg = field[1];
        }
        else {
            fieldname = msg = field;
        }
        const value = fieldname ? obj[fieldname] : obj;
        if (!Checker.has(value)) {
            if (defaultValue !== undefined) {
                if (fieldname)
                    obj[fieldname] = defaultValue;
                else
                    obj = defaultValue;
            }
            return false;
        }
        if (type)
            Checker.is(value, type, msg);
        return true;
    }
    static required(obj, field, type) {
        let fieldname;
        let msg;
        if (field instanceof Array) {
            fieldname = field[0];
            msg = field[1];
        }
        else {
            fieldname = msg = field;
        }
        const value = fieldname ? obj[fieldname] : obj;
        if (!Checker.has(value))
            throw HttpError_1.default.BAD_REQUEST(`${msg} is required`);
        if (type)
            Checker.is(value, type, msg);
    }
    static has(value) {
        return value !== undefined && value !== null && value !== '';
    }
}
exports.Checker = Checker;
